( cd usr/lib/mozilla-1.7.13/plugins ; rm -rf libjavaplugin_oji.so )
( cd usr/lib/mozilla-1.7.13/plugins ; ln -sf /usr/lib/java/plugin/i386/ns7/libjavaplugin_oji.so libjavaplugin_oji.so
)
( cd usr/lib/mozilla-1.7.13/plugins ; rm -rf libflashplayer.so )
( cd usr/lib/mozilla-1.7.13/plugins ; ln -sf /usr/lib/netscape/plugins/libflashplayer.so libflashplayer.so )
